=== modified file 'bzrlib/config.py'
--- bzrlib/config.py	2014-06-19 09:42:08 +0000
+++ bzrlib/config.py	2016-01-21 11:42:23 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2012 Canonical Ltd
+# Copyright (C) 2005-2014, 2016 Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #            and others
 #
@@ -2550,7 +2550,7 @@
         return "".join(ret)
 
 
-_option_ref_re = lazy_regex.lazy_compile('({[^\d\W](?:\.\w|\w)*})')
+_option_ref_re = lazy_regex.lazy_compile('({[^\d\W](?:\.\w|-\w|\w)*})')
 """Describes an expandable option reference.
 
 We want to match the most embedded reference first.

=== modified file 'bzrlib/gpg.py'
--- bzrlib/gpg.py	2013-11-10 15:29:06 +0000
+++ bzrlib/gpg.py	2016-01-21 09:52:36 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2011 Canonical Ltd
+# Copyright (C) 2005, 2006, 2007, 2009, 2011, 2012, 2013, 2016 Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -322,12 +322,13 @@
                 return SIGNATURE_NOT_VALID, None
         # A signature from a revoked key gets this.
         # test_verify_revoked_signature()
-        if result[0].summary & gpgme.SIGSUM_SYS_ERROR:
+        if ((result[0].summary & gpgme.SIGSUM_SYS_ERROR
+             or result[0].status.strerror == 'Certificate revoked')):
             return SIGNATURE_NOT_VALID, None
         # Other error types such as revoked keys should (I think) be caught by
         # SIGSUM_RED so anything else means something is buggy.
-        raise errors.SignatureVerificationFailed("Unknown GnuPG key "\
-                                                 "verification result")
+        raise errors.SignatureVerificationFailed(
+            "Unknown GnuPG key verification result")
 
     def set_acceptable_keys(self, command_line_input):
         """Set the acceptable keys for verifying with this GPGStrategy.

=== modified file 'bzrlib/tests/per_transport.py'
--- bzrlib/tests/per_transport.py	2016-01-21 17:48:07 +0000
+++ bzrlib/tests/per_transport.py	2016-01-22 08:02:12 +0000
@@ -609,10 +609,13 @@
     def test_opening_a_file_stream_can_set_mode(self):
         t = self.get_transport()
         if t.is_readonly():
+            self.assertRaises((TransportNotPossible, NotImplementedError),
+                              t.open_write_stream, 'foo')
             return
         if not t._can_roundtrip_unix_modebits():
             # Can't roundtrip, so no need to run this test
             return
+
         def check_mode(name, mode, expected):
             handle = t.open_write_stream(name, mode=mode)
             handle.close()
@@ -900,7 +903,9 @@
     def test_rename_dir_succeeds(self):
         t = self.get_transport()
         if t.is_readonly():
-            raise TestSkipped("transport is readonly")
+            self.assertRaises((TransportNotPossible, NotImplementedError),
+                              t.rename, 'foo', 'bar')
+            return
         t.mkdir('adir')
         t.mkdir('adir/asubdir')
         t.rename('adir', 'bdir')
@@ -911,7 +916,9 @@
         """Attempting to replace a nonemtpy directory should fail"""
         t = self.get_transport()
         if t.is_readonly():
-            raise TestSkipped("transport is readonly")
+            self.assertRaises((TransportNotPossible, NotImplementedError),
+                              t.rename, 'foo', 'bar')
+            return
         t.mkdir('adir')
         t.mkdir('adir/asubdir')
         t.mkdir('bdir')

=== modified file 'bzrlib/tests/test_config.py'
--- bzrlib/tests/test_config.py	2016-01-14 14:10:33 +0000
+++ bzrlib/tests/test_config.py	2016-01-21 11:42:23 +0000
@@ -2237,6 +2237,8 @@
         self.assertTrue(self.is_valid('__bar__'))
         self.assertTrue(self.is_valid('a_'))
         self.assertTrue(self.is_valid('a1'))
+        # Don't break bzr-svn for no good reason
+        self.assertTrue(self.is_valid('guessed-layout'))
 
     def test_invalid_names(self):
         self.assertFalse(self.is_valid(' foo'))
@@ -2250,6 +2252,10 @@
         self.assertFalse(self.is_valid('{}'))
         self.assertFalse(self.is_valid('{a}'))
         self.assertFalse(self.is_valid('a\n'))
+        self.assertFalse(self.is_valid('-'))
+        self.assertFalse(self.is_valid('-a'))
+        self.assertFalse(self.is_valid('a-'))
+        self.assertFalse(self.is_valid('a--a'))
 
     def assertSingleGroup(self, reference):
         # the regexp is used with split and as such should match the reference

=== modified file 'bzrlib/tests/test_smart_transport.py'
--- bzrlib/tests/test_smart_transport.py	2014-02-07 10:20:38 +0000
+++ bzrlib/tests/test_smart_transport.py	2016-01-22 08:02:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2011 Canonical Ltd
+# Copyright (C) 2006-2014, 2016 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -1640,6 +1640,21 @@
         self.assertRaises(errors.TransportNotPossible, self.transport.mkdir,
             'foo')
 
+    def test_rename_error_readonly(self):
+        """TransportNotPossible should be preserved from the backing transport."""
+        self.overrideEnv('BZR_NO_SMART_VFS', None)
+        self.start_server(readonly=True)
+        self.assertRaises(errors.TransportNotPossible, self.transport.rename,
+                          'foo', 'bar')
+
+    def test_open_write_stream_error_readonly(self):
+        """TransportNotPossible should be preserved from the backing transport."""
+        self.overrideEnv('BZR_NO_SMART_VFS', None)
+        self.start_server(readonly=True)
+        self.assertRaises(
+            errors.TransportNotPossible, self.transport.open_write_stream,
+            'foo')
+
 
 class TestServerHooks(SmartTCPTests):
 

=== modified file 'bzrlib/transport/readonly.py'
--- bzrlib/transport/readonly.py	2011-12-19 13:23:58 +0000
+++ bzrlib/transport/readonly.py	2016-01-22 08:02:12 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2009 Canonical Ltd
+# Copyright (C) 2006, 2007, 2009, 2010, 2011, 2016 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -41,6 +41,10 @@
         """Readonly transport decorators are invoked via 'readonly+'"""
         return 'readonly+'
 
+    def rename(self, rel_from, rel_to):
+        """See Transport.rename."""
+        raise TransportNotPossible('readonly transport')
+
     def delete(self, relpath):
         """See Transport.delete()."""
         raise TransportNotPossible('readonly transport')
@@ -61,6 +65,10 @@
         """See Transport.mkdir()."""
         raise TransportNotPossible('readonly transport')
 
+    def open_write_stream(self, relpath, mode=None):
+        """See Transport.open_write_stream()."""
+        raise TransportNotPossible('readonly transport')
+
     def is_readonly(self):
         """See Transport.is_readonly."""
         return True
@@ -74,7 +82,7 @@
         raise TransportNotPossible('readonly transport')
 
     def get_smart_client(self):
-        raise NoSmartServer(self.base)
+        raise NoSmartMedium(self)
 
     def get_smart_medium(self):
         raise NoSmartMedium(self)
@@ -83,4 +91,4 @@
 def get_test_permutations():
     """Return the permutations to be used in testing."""
     from bzrlib.tests import test_server
-    return [(ReadonlyTransportDecorator, test_server.ReadonlyServer),]
+    return [(ReadonlyTransportDecorator, test_server.ReadonlyServer)]

=== modified file 'doc/en/release-notes/bzr-2.7.txt'
--- doc/en/release-notes/bzr-2.7.txt	2016-01-21 17:48:07 +0000
+++ doc/en/release-notes/bzr-2.7.txt	2016-01-22 08:02:12 +0000
@@ -39,13 +39,16 @@
 * 'acceptable_keys' from 'bazaar.conf' is now properly handled.
   (Vincent Ladeuil, #1249732)
 
-* Option names are now checked to be valid [dotted] python identifiers. Also
-  ignore invalid references (i.e. using invalid option names) while
-  expanding option values. (Vincent Ladeuil, #1235099)
+* Option names are now checked to be valid identifiers (including embedded
+  dots or hyphens). Also ignore invalid references (i.e. using invalid
+  option names) while expanding option values. (Vincent Ladeuil, #1235099)
 
 * Fix pyrex version checking to be more robust.
   (Andrew Starr-Bochicchio, #1030521 )
 
+* Forbid more operations for ReadonlyTransportDecorator so no more write
+  methods can be used my mistake.  (Vincent Ladeuil, #150196)
+
 Documentation
 *************
 
@@ -80,6 +83,8 @@
    suite.  This can include new facilities for writing tests, fixes to 
    spurious test failures and changes to the way things should be tested.
 
+* Fix gpgme test failure starting on wily. (Vincent Ladeuil)
+     
 * Fix racy http tests (TestBadStatusServer is so simple, it exposes a race
   in python 2.7.9. This happens only when both the http server and client
   are run in the same process.). Only tests are affected.

